@@ -21,7 +21,8 @@ use IO::SessionData;
 
 # ======================================================================
 
-package URI::tcp; # ok, let's do 'tcp://' scheme
+package # hide from PAUSE
+    URI::tcp; # ok, let's do 'tcp://' scheme
 
 our $VERSION = 0.715;
 
@@ -309,4 +310,4 @@ Written by Paul Kulchenko.
 
 Split from SOAP::Lite and SOAP-Transport-TCP packaging by Martin Kutter
 
-=cut
\ No newline at end of file
+=cut
